duckdb_file_handle_tell

Function duckdb_file_handle_tell 

pub unsafe extern "C" fn duckdb_file_handle_tell(
    file_handle: duckdb_file_handle,
) -> i64
Tells the current position in the file.

@param file_handle The file handle to tell the position of. @return The current position in the file, or negative on error.