duckdb_file_open_options_set_flag

Function duckdb_file_open_options_set_flag 

pub unsafe extern "C" fn duckdb_file_open_options_set_flag(
    options: duckdb_file_open_options,
    flag: duckdb_file_flag,
    value: bool,
) -> duckdb_state
Sets a specific flag in the file open options.

@param options The file open options instance. @param flag The flag to set (e.g., read, write). @param value If the flag is enabled or disabled. @return DuckDBSuccess on success or DuckDBError if the flag is unrecognized or unsupported by this version of DuckDB.