duckdb_value_varchar

Function duckdb_value_varchar 

pub unsafe extern "C" fn duckdb_value_varchar(
    result: *mut duckdb_result,
    col: idx_t,
    row: idx_t,
) -> *mut c_char
DEPRECATION NOTICE**: This method is scheduled for removal in a future release.

@return The text value at the specified location as a null-terminated string, or nullptr if the value cannot be converted. The result must be freed with duckdb_free.