pub unsafe extern "C" fn duckdb_catalog_entry_get_name(
entry: duckdb_catalog_entry,
) -> *const c_charExpand description
Get the name of the given catalog entry.
@param entry The catalog entry. @return The name of the catalog entry. The returned string is owned by the catalog entry and remains valid until the catalog entry is destroyed.