pub unsafe extern "C" fn duckdb_client_context_get_config_option(
context: duckdb_client_context,
name: *const c_char,
out_scope: *mut duckdb_config_option_scope,
) -> duckdb_valueExpand description
Retrieves the value of a configuration option by name from the given client context.
@param context The client context.
@param name The name of the configuration option to retrieve.
@param out_scope Output parameter to optionally store the scope that the configuration option was retrieved from.
If this is nullptr, the scope is not returned.
If the requested option does not exist the scope is set to DUCKDB_CONFIG_OPTION_SCOPE_INVALID.
@return The value of the configuration option. Returns nullptr if the option does not exist.