pub unsafe extern "C" fn duckdb_destroy_file_handle(
file_handle: *mut duckdb_file_handle,
)Expand description
Destroys the given file handle and deallocates all associated resources. This will also close the file if it is still open.
@param file_handle The file handle to destroy.