pub unsafe extern "C" fn duckdb_file_handle_size(
file_handle: duckdb_file_handle,
) -> i64Expand description
Gets the size of the file.
@param file_handle The file handle to get the size of. @return The size of the file in bytes, or negative on error.