pub unsafe extern "C" fn duckdb_file_handle_tell(
file_handle: duckdb_file_handle,
) -> i64Expand description
Tells the current position in the file.
@param file_handle The file handle to tell the position of. @return The current position in the file, or negative on error.